@@ -6,7 +6,7 @@ from __future__ import annotations
 
 from .pybary import bary_batch, bary_recursive
 
-__author__ = 'Bruno Peixoto'
-__email__ = 'brunolnetto@gmail.com'
+__author__ = "Bruno Peixoto"
+__email__ = "brunolnetto@gmail.com"
 
-__all__ = ['bary_batch', 'bary_recursive']
+__all__ = ["bary_batch", "bary_recursive"]
